
The documentation pertaining to YAML syntax is [here](kgsteward.schema.md)

*Nota Bene*: the files `kgsteward.schema.json` and `kgsteward.schema.md` are autogenerated with the command

```sh
cd <here>
uv run make_yaml_README.py
```

